/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "PN1CoincidenceDetectorElement.h"

namespace npp {

const string PN1CoincidenceDetectorElement::TYPE = "pn1_coincidence_detector_element";

/*
 * Constructor
 */
PN1CoincidenceDetectorElement::PN1CoincidenceDetectorElement(const string& name) :
	acquisition::DetectorElement(name) {

	registerFunction(TYPE);

	m_Driver.init(this, "driver");
}

/*
 * Destructor
 */
PN1CoincidenceDetectorElement::~PN1CoincidenceDetectorElement() {

}

/*
 * postConfiguration
 */
void PN1CoincidenceDetectorElement::postConfiguration() {

	acquisition::DetectorElement::postConfiguration();
	registerUpdater(m_Driver->pn1ConicidenceZData, &PN1CoincidenceDetectorElement::updateData, this);
}

/*
 * updateData
 */
void PN1CoincidenceDetectorElement::updateData() {

	detSize = m_Driver->pn1ConicidenceZData.getSize();
	int32* ldata =  m_Driver->pn1ConicidenceZData();
	data.update(ldata);
	data.setSize(detSize());
	data.sendEvent();
	calculateDetectorSum();
}

}
