/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include <InstrumentManager/InstrumentManager.h>
#include <controllers/common/acquisition/Count.h>
#include <controllers/common/scanlegacy/ScanInfo.h>
#include <ics/Utilities/Calculations.h>
#include <fstream>
#include <iostream>
#include <common/base/ServerProperties.h>
#include "controllers/common/family/Families.h"
#include "RemoteMatlab.h"

namespace tas {

using namespace std;
using namespace common;
using namespace boost;
using namespace cameo;

const std::string RemoteMatlab::TYPE = "tas_base_matlab";

RemoteMatlab::RemoteMatlab(const std::string& name) :
	utilities::ImageData(name),
	controller::Start(this) {

	setFamily(family::ACQUISITION);

	serverEndpoint.init(this, SAVE, "cameo_server");
	initialized.init(this, NOSAVE, "initialized");
	test.init(this, SAVE, "test");
	testNumor.init(this, SAVE, "test_numor");
	active.init(this, NOSAVE, "active");

	scanController.init(this, "scan");
	countSpy.init(this, "acquisition_spy");
	tasSettings.init(this, "settings");

	experimentData.assign(InstrumentManager::getInstance()->getFirstExperimentControllerByType("title"));
}

RemoteMatlab::~RemoteMatlab() {
}

void RemoteMatlab::postConfiguration() {

	registerUpdater(tasSettings->mode, &RemoteMatlab::updateSettingsMode, this);

	updateSettingsMode();
}

void RemoteMatlab::updateSettingsMode() {

	// RemoteMatlab is only active in case of flatcone.
	active = (tasSettings->mode() == tas::TasSettings::FLATCONE_MODE);
}

string RemoteMatlab::getProposalId() const {
	return experimentData->proposalId();
}

string RemoteMatlab::getProposalName() const {
	return experimentData->experimentNumber();
}

string RemoteMatlab::getInstrumentId() const {
	return experimentData->instrumentId();
}

string RemoteMatlab::getInstrumentName() const {
	return experimentData->instrumentName();
}

string RemoteMatlab::getSampleId() const {
	return experimentData->sampleId();
}

string RemoteMatlab::getSampleName() const {
	return experimentData->chemicalFormula();
}

string RemoteMatlab::getCycleId() const {
	return experimentData->cycleId();
}

}
